==> mastercard_mastercom-5.0.0.tar.gz: mastercard_mastercom-5.0.0/mastercardmastercom/reconciliation.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmastercom import ResourceConfig

class Reconciliation(BaseObject):
    """
    
    """

    __config = {
        
        "c8cd8d69-2aaf-4ca1-9246-d2ddb64c7995" : OperationConfig("/mastercom/v5/reconreport/data/request", "create", [], []),
        
        "3421c461-4e02-4f1a-b128-6514d72f391f" : OperationConfig("/mastercom/v5/reconreport/data/retrieval/{reportIdentifier}", "create", [], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def acknowledgeReconciliationRequest(cls,mapObj):
        """
        Creates object of type Reconciliation

        @param Dict mapObj, containing the required parameters to create a new object
        @return Reconciliation of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("c8cd8d69-2aaf-4ca1-9246-d2ddb64c7995", Reconciliation(mapObj))






    @classmethod
    def retrieveReconciliationReport(cls,mapObj):
        """
        Creates object of type Reconciliation

        @param Dict mapObj, containing the required parameters to create a new object
        @return Reconciliation of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("3421c461-4e02-4f1a-b128-6514d72f391f", Reconciliation(mapObj))

==> mastercard_mastercom-6.0.0.tar.gz: mastercard_mastercom-6.0.0/mastercardmastercom/reconciliation.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmastercom import ResourceConfig

class Reconciliation(BaseObject):
    """
    
    """

    __config = {
        
        "97b16f8f-9e79-41b3-9c0d-2f77fd1c4ef4" : OperationConfig("/mastercom/v6/reconreport/data/request", "create", [], []),
        
        "19aab390-af70-41e0-a32f-58a7b1ca1a38" : OperationConfig("/mastercom/v6/reconreport/data/retrieval/{reportIdentifier}", "create", [], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def acknowledgeReconciliationRequest(cls,mapObj):
        """
        Creates object of type Reconciliation

        @param Dict mapObj, containing the required parameters to create a new object
        @return Reconciliation of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("97b16f8f-9e79-41b3-9c0d-2f77fd1c4ef4", Reconciliation(mapObj))






    @classmethod
    def retrieveReconciliationReport(cls,mapObj):
        """
        Creates object of type Reconciliation

        @param Dict mapObj, containing the required parameters to create a new object
        @return Reconciliation of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("19aab390-af70-41e0-a32f-58a7b1ca1a38", Reconciliation(mapObj))
